@@ -1,21 +1,7 @@
 /*
  *  Copyright 2018-2019  Andreas Cord-Landwehr <cordlandwehr@kde.org>
  *
- *  This program is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU General Public License as
- *  published by the Free Software Foundation; either version 2 of
- *  the License or (at your option) version 3 or any later version
- *  accepted by the membership of KDE e.V. (or its successor approved
- *  by the membership of KDE e.V.), which shall act as a proxy
- *  defined in Section 14 of version 3 of the license.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *  SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
 #ifndef TRAININGACTION_H
@@ -25,8 +11,8 @@
 #include "iphrase.h"
 #include "trainingactionicon.h"
 #include "trainingsession.h"
-#include <QDebug>
 #include <QAbstractItemModel>
+#include <QDebug>
 #include <QObject>
 
 class DrawerTrainingActions;
@@ -37,21 +23,20 @@ class ARTIKULATECORE_EXPORT TrainingAction : public QAbstractListModel
     Q_PROPERTY(QString text READ text WRITE setText NOTIFY textChanged)
     Q_PROPERTY(QString title READ text WRITE setText NOTIFY textChanged)
     Q_PROPERTY(QObject *icon READ icon CONSTANT)
+    Q_PROPERTY(QObject *parent READ parent WRITE setParent CONSTANT)
     Q_PROPERTY(bool visible MEMBER m_visible CONSTANT)
     Q_PROPERTY(bool enabled READ enabled WRITE setEnabled NOTIFY enabledChanged)
     Q_PROPERTY(bool checked READ checked NOTIFY checkedChanged)
     Q_PROPERTY(QString tooltip MEMBER m_tooltip CONSTANT)
-    Q_PROPERTY(QAbstractItemModel * children READ actionModel NOTIFY actionsChanged)
+    Q_PROPERTY(QAbstractItemModel *children READ actionModel NOTIFY actionsChanged)
     Q_PROPERTY(bool checkable MEMBER m_checkable CONSTANT)
     Q_PROPERTY(int length READ actionsCount NOTIFY actionsChanged)
 
 public:
-    enum ModelRoles {
-        ModelDataRole = Qt::UserRole + 1
-    };
+    enum ModelRoles { ModelDataRole = Qt::UserRole + 1 };
 
-    TrainingAction(QObject *parent = nullptr);
-    TrainingAction(const QString &text, QObject *parent = nullptr);
+    explicit TrainingAction(QObject *parent = nullptr);
+    explicit TrainingAction(const QString &text, QObject *parent = nullptr);
     TrainingAction(std::shared_ptr<IPhrase> phrase, ISessionActions *session, QObject *parent = nullptr);
     Q_INVOKABLE void trigger();
     bool enabled() const;
@@ -62,11 +47,14 @@ public:
     bool checked() const;
     QObject *icon();
     IPhrase *phrase() const;
-    QAbstractListModel * actionModel();
-    QVector<TrainingAction*> actions() const;
+    QAbstractListModel *actionModel();
+    QVector<TrainingAction *> actions() const;
     int actionsCount() const;
-    bool hasActions() { return m_actions.count() > 0; }
-    TrainingAction * action(int index) const;
+    bool hasActions()
+    {
+        return m_actions.count() > 0;
+    }
+    TrainingAction *action(int index) const;
     void appendAction(TrainingAction *action);
     void clearActions();
     QHash<int, QByteArray> roleNames() const override;
